@@ -13,8 +13,14 @@ class Profile(models.Model):
     user = models.ForeignKey('auth.User')
     is_public = models.BooleanField()
 
+    def is_attached_to_user(self, user):
+        return self.user == user
+
 
 class AnonymousProfile(object):
 
     user = None
     is_public = False
+
+    def is_attached_to_user(self, user):
+        return False
\ No newline at end of file
