@@ -11,11 +11,11 @@ from django.utils import importlib
 def get_class(module_name, cls_name):
     try:
         module = importlib.import_module(module_name)
-    except ImportError:
-        raise ImportError('Invalid class path: {}'.format(module_name))
+    except ImportError as exc:
+        raise ImportError('Cannot import class "{}"'.format('.'.join((module_name, cls_name))))
     try:
         cls = getattr(module, cls_name)
     except AttributeError:
-        raise ImportError('Invalid class name: {}'.format(cls_name))
+        raise ImportError('Class "{}" not found in {}'.format(cls_name, module_name))
     else:
         return cls
